@@ -6,9 +6,9 @@ You can find the current version in the command line interface:
 .. sourcecode:: console
 
    $ python -m wand.version
-   0.2.2
+   0.0.0
    $ python -m wand.version --verbose
-   Wand 0.2.2
+   Wand 0.0.0
    ImageMagick 6.7.7-6 2012-06-03 Q16 http://www.imagemagick.org
 
 .. versionadded:: 0.2.0
@@ -19,6 +19,8 @@ You can find the current version in the command line interface:
    version for CLI.
 
 """
+from __future__ import print_function
+
 import ctypes
 import datetime
 import re
@@ -28,17 +30,19 @@ try:
     from .api import libmagick
 except ImportError:
     libmagick = None
+from .compat import text
 
 
 __all__ = ('VERSION', 'VERSION_INFO', 'MAGICK_VERSION',
            'MAGICK_VERSION_INFO', 'MAGICK_VERSION_NUMBER',
-           'MAGICK_RELEASE_DATE', 'MAGICK_RELEASE_DATE_STRING')
+           'MAGICK_RELEASE_DATE', 'MAGICK_RELEASE_DATE_STRING',
+           'QUANTUM_DEPTH')
 
 #: (:class:`tuple`) The version tuple e.g. ``(0, 1, 2)``.
 #:
 #: .. versionchanged:: 0.1.9
 #:    Becomes :class:`tuple`.  (It was string before.)
-VERSION_INFO = (0, 2, 4)
+VERSION_INFO = (0, 3, 0)
 
 #: (:class:`basestring`) The version string e.g. ``'0.1.2'``.
 #:
@@ -57,7 +61,9 @@ if libmagick:
     #:    'ImageMagick 6.7.7-6 2012-06-03 Q16 http://www.imagemagick.org'
     #:
     #: .. versionadded:: 0.2.1
-    MAGICK_VERSION = libmagick.GetMagickVersion(ctypes.byref(c_magick_version))
+    MAGICK_VERSION = text(
+        libmagick.GetMagickVersion(ctypes.byref(c_magick_version))
+    )
 
     #: (:class:`numbers.Integral`) The version number of the linked
     #: ImageMagick library.
@@ -78,7 +84,7 @@ if libmagick:
     #: function.
     #:
     #: .. versionadded:: 0.2.1
-    MAGICK_RELEASE_DATE_STRING = libmagick.GetMagickReleaseDate()
+    MAGICK_RELEASE_DATE_STRING = text(libmagick.GetMagickReleaseDate())
 
     #: (:class:`basestring`) The date string e.g. ``'2012-06-03'`` of
     #: :const:`MAGICK_RELEASE_DATE_STRING`.  This value is the exactly same
@@ -88,20 +94,28 @@ if libmagick:
     MAGICK_RELEASE_DATE = datetime.date(
         *map(int, MAGICK_RELEASE_DATE_STRING.split('-')))
 
-    del c_magick_version, _match
+    c_quantum_depth = ctypes.c_size_t()
+    libmagick.GetMagickQuantumDepth(ctypes.byref(c_quantum_depth))
+    #: (:class:`numbers.Integral`) The quantum depth configuration of
+    #: the linked ImageMagick library.  One of 8, 16, 32, or 64.
+    #:
+    #: .. versionadded:: 0.3.0
+    QUANTUM_DEPTH = c_quantum_depth.value
 
-__doc__ = __doc__.replace('0.2.2', VERSION)
+    del c_magick_version, _match, c_quantum_depth
+
+__doc__ = __doc__.replace('0.0.0', VERSION)
 del libmagick
 
 
 if __name__ == '__main__':
     options = frozenset(sys.argv[1:])
     if '-v' in options or '--verbose' in options:
-        print 'Wand', VERSION
+        print('Wand', VERSION)
         try:
-            print MAGICK_VERSION
+            print(MAGICK_VERSION)
         except NameError:
             pass
     else:
-        print VERSION
+        print(VERSION)
 
